PEP: 619 Title: Python 3.10 Release Schedule Version: \$Revision\$
Last-Modified: \$Date\$ Author: Pablo Galindo Salgado
\<<pablogsal@python.org>\> Status: Draft Type: Informational
Content-Type: text/x-rst Created: 25-May-2020 Python-Version: 3.10

Abstract
========

This document describes the development and release schedule for Python
3.10. The schedule primarily concerns itself with PEP-sized items.

Release Manager and Crew
========================

-   3.10 Release Manager: Pablo Galindo Salgado
-   Windows installers: Steve Dower
-   Mac installers: Ned Deily
-   Documentation: Julien Palard

Release Schedule
================

3.10.0 schedule
---------------

Note: the dates below use a 17-month development period that results in
a 12-month release cadence between major versions, as defined by PEP
602.

Actual:

-   3.10 development begins: Monday, 2020-05-18

Expected:

-   3.10.0 alpha 1: Monday, 2020-10-05
-   3.10.0 alpha 2: Monday, 2020-11-02
-   3.10.0 alpha 3: Monday, 2020-12-07
-   3.10.0 alpha 4: Monday, 2021-01-04
-   3.10.0 alpha 5: Monday, 2021-02-01
-   3.10.0 alpha 6: Monday, 2021-03-01
-   3.10.0 alpha 7: Monday, 2021-04-05
-   3.10.0 beta 1: Monday, 2021-05-03 (No new features beyond this
    point.)
-   3.10.0 beta 2: Tuesday, 2021-05-25
-   3.10.0 beta 3: Thursday, 2021-06-17
-   3.10.0 beta 4: Saturday, 2021-07-10
-   3.10.0 candidate 1: Monday, 2021-08-02
-   3.10.0 candidate 2: Monday, 2021-09-06 (if necessary)
-   3.10.0 final: Monday, 2021-10-04

Subsequent bugfix releases every two months.

3.10 Lifespan
-------------

3.10 will receive bugfix updates approximately every 2 months for
approximately 18 months. Some time after the release of 3.11.0 final,
the ninth and final 3.10 bugfix update will be released. After that, it
is expected that security updates (source only) will be released until 5
years after the release of 3.10 final, so until approximately October
2026.

Features for 3.10
=================

Some of the notable features of Python 3.10 include:

-   `618`{.interpreted-text role="pep"}, Add Optional Length-Checking To
    `zip`

Copyright
=========

This document has been placed in the public domain.
